@@ -76,6 +76,7 @@ class AutomationDefinition(Definition):
             validate_environment_variables,
             validate_display_styles,
             validate_display_templates,
+            validate_print,
         ]
 
     def get_variable_definitions(self, mode_name, with_all=False):
@@ -203,6 +204,16 @@ class StyleDefinition(Definition):
         ]
 
 
+class PrintDefinition(Definition):
+
+    def _initialize(self, kwargs):
+        self._validation_functions = [
+            validate_print_configuration,
+            validate_header_footer_options,
+            validate_page_number_options,
+        ]
+
+
 def save_raw_configuration(configuration_path, configuration):
     configuration_format = get_configuration_format(configuration_path)
     save_raw_configuration = {
@@ -451,14 +462,14 @@ def validate_scripts(configuration):
 
 
 def validate_display_styles(configuration):
-    display_configuration = get_dictionary(configuration, 'display')
+    display_dictionary = get_dictionary(configuration, 'display')
     automation_folder = configuration.folder
     automation_index = configuration.index
     automation_uri = configuration.uri
     reference_time = time()
     style_definitions = []
     for raw_style_definition in get_dictionaries(
-            display_configuration, 'styles'):
+            display_dictionary, 'styles'):
         style_definition = StyleDefinition(raw_style_definition)
         style_uri = style_definition.uri
         style_path = style_definition.path
@@ -483,10 +494,10 @@ def validate_display_styles(configuration):
 
 
 def validate_display_templates(configuration):
-    display_configuration = get_dictionary(configuration, 'display')
+    display_dictionary = get_dictionary(configuration, 'display')
     template_path_by_id = {}
     for raw_template_definition in get_dictionaries(
-            display_configuration, 'templates'):
+            display_dictionary, 'templates'):
         template_definition = TemplateDefinition(raw_template_definition)
         template_id = template_definition.id
         template_path_by_id[template_id] = template_definition.path
@@ -495,6 +506,13 @@ def validate_display_templates(configuration):
     }
 
 
+def validate_print(configuration):
+    print_dictionary = get_dictionary(configuration, 'print')
+    return {
+        'print_definition': PrintDefinition(print_dictionary),
+    }
+
+
 def validate_template_identifiers(template_definition):
     try:
         template_path = template_definition['path']
@@ -638,6 +656,37 @@ def validate_style_identifiers(style_definition):
     }
 
 
+def validate_print_configuration(print_dictionary):
+    print_configuration = get_dictionary(
+        print_dictionary, 'configuration')
+    return {
+        'configuration': print_configuration,
+    }
+
+
+def validate_header_footer_options(print_dictionary):
+    print_configuration = print_dictionary.configuration
+    key = 'header-footer'
+    options = get_dictionary(print_configuration, key)
+    options['skip-first'] = bool(options.get('skip-first'))
+    return {}
+
+
+def validate_page_number_options(print_dictionary):
+    print_configuration = print_dictionary.configuration
+    key = 'page-number'
+    options = get_dictionary(print_configuration, key)
+    location = options.get('location')
+    if location and location not in ['header', 'footer']:
+        raise CrossComputeConfigurationError(
+            f'{location} location not supported for {key}')
+    alignment = options.get('alignment')
+    if alignment and alignment not in ['left', 'center', 'right']:
+        raise CrossComputeConfigurationError(
+            f'{alignment} alignment not supported for {key}')
+    return {}
+
+
 def get_configuration_format(path):
     file_extension = path.suffix
     try:
